@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2015 the original author or authors.
+// Copyright (C) 2001-2016 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,7 @@ import org.apache.commons.beanutils.ConversionException;
 
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.Lists;
+import com.puppycrawl.tools.checkstyle.api.AuditEvent;
 import com.puppycrawl.tools.checkstyle.api.Check;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -142,16 +143,17 @@ public class SuppressWarningsHolder
     /**
      * Checks for a suppression of a check with the given source name and
      * location in the last file processed.
-     * @param sourceName the source name of the check
-     * @param line the line number of the check
-     * @param column the column number of the check
+     * @param event audit event.
      * @return whether the check with the given name is suppressed at the given
      *         source location
      */
-    public static boolean isSuppressed(String sourceName, int line,
-        int column) {
+    public static boolean isSuppressed(AuditEvent event) {
         final List<Entry> entries = ENTRIES.get();
+        final String sourceName = event.getSourceName();
         final String checkAlias = getAlias(sourceName);
+        final int line = event.getLine();
+        final int column = event.getColumn();
+        boolean suppressed = false;
         for (Entry entry : entries) {
             final boolean afterStart =
                 entry.getFirstLine() < line
@@ -164,11 +166,13 @@ public class SuppressWarningsHolder
             final boolean nameMatches =
                 ALL_WARNING_MATCHING_ID.equals(entry.getCheckName())
                     || entry.getCheckName().equalsIgnoreCase(checkAlias);
-            if (afterStart && beforeEnd && nameMatches) {
-                return true;
+            final boolean idMatches = event.getModuleId() != null
+                && event.getModuleId().equals(entry.getCheckName());
+            if (afterStart && beforeEnd && (nameMatches || idMatches)) {
+                suppressed = true;
             }
         }
-        return false;
+        return suppressed;
     }
 
     @Override
@@ -329,7 +333,7 @@ public class SuppressWarningsHolder
      * @return returns ast - parent of given
      */
     private static DetailAST getAcceptableParent(DetailAST child) {
-        DetailAST result;
+        final DetailAST result;
         final DetailAST parent = child.getParent();
         switch (parent.getType()) {
             case TokenTypes.ANNOTATION_DEF:
