@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2015 the original author or authors.
+// Copyright (C) 2001-2016 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -376,7 +376,7 @@ public class EqualsAvoidNullCheck extends Check {
      * @return true if the object is of String type.
      */
     private boolean isCalledOnStringFieldOrVariable(DetailAST objCalledOn) {
-        boolean result;
+        final boolean result;
         final DetailAST previousSiblingAst = objCalledOn.getPreviousSibling();
         if (previousSiblingAst == null) {
             result = isStringFieldOrVariable(objCalledOn);
