@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2015 the original author or authors.
+// Copyright (C) 2001-2016 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -249,7 +249,7 @@ public class ImportOrderCheck
         for (int i = 0; i < packageGroups.length; i++) {
             String pkg = packageGroups[i];
             final StringBuilder pkgBuilder = new StringBuilder(pkg);
-            Pattern grp;
+            final Pattern grp;
 
             // if the pkg name is the wildcard, make it match zero chars
             // from any name, so it will always be used as last resort.
@@ -532,7 +532,7 @@ public class ImportOrderCheck
      */
     private static int compare(String string1, String string2,
             boolean caseSensitive) {
-        int result;
+        final int result;
         if (caseSensitive) {
             result = string1.compareTo(string2);
         }
