@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2015 the original author or authors.
+// Copyright (C) 2001-2016 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -43,6 +43,7 @@ import com.puppycrawl.tools.checkstyle.api.JavadocTokenTypes;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.grammars.javadoc.JavadocLexer;
 import com.puppycrawl.tools.checkstyle.grammars.javadoc.JavadocParser;
+import com.puppycrawl.tools.checkstyle.utils.BlockCommentPosition;
 import com.puppycrawl.tools.checkstyle.utils.JavadocUtils;
 
 /**
@@ -53,12 +54,12 @@ public abstract class AbstractJavadocCheck extends Check {
     /**
      * Error message key for common javadoc errors.
      */
-    public static final String PARSE_ERROR_MESSAGE_KEY = "javadoc.parse.error";
+    public static final String MSG_KEY_PARSE_ERROR = "javadoc.parse.error";
 
     /**
      * Unrecognized error from antlr parser.
      */
-    public static final String UNRECOGNIZED_ANTLR_ERROR_MESSAGE_KEY =
+    public static final String MSG_KEY_UNRECOGNIZED_ANTLR_ERROR =
             "javadoc.unrecognized.antlr.error";
     /**
      * Message key of error message. Missed close HTML tag breaks structure
@@ -67,13 +68,18 @@ public abstract class AbstractJavadocCheck extends Check {
      * {@code "no viable alternative at input 'b \n *\n'"} and it is not
      * clear that error is about missed close HTML tag.
      */
-    static final String JAVADOC_MISSED_HTML_CLOSE = "javadoc.missed.html.close";
+    public static final String MSG_JAVADOC_MISSED_HTML_CLOSE = "javadoc.missed.html.close";
     /**
      * Message key of error message.
      */
-    static final String JAVADOC_WRONG_SINGLETON_TAG =
+    public static final String MSG_JAVADOC_WRONG_SINGLETON_TAG =
         "javadoc.wrong.singleton.html.tag";
 
+    /**
+     * Parse error while rule recognition.
+     */
+    public static final String MSG_JAVADOC_PARSE_RULE_ERROR = "javadoc.parse.rule.error";
+
     /**
      * Key is "line:column". Value is {@link DetailNode} tree. Map is stored in {@link ThreadLocal}
      * to guarantee basic thread safety and avoid shared, mutable state when not necessary.
@@ -168,14 +174,15 @@ public abstract class AbstractJavadocCheck extends Check {
 
     @Override
     public final void visitToken(DetailAST blockCommentNode) {
-        if (JavadocUtils.isJavadocComment(blockCommentNode)) {
+        if (JavadocUtils.isJavadocComment(blockCommentNode)
+              && isCorrectJavadocPosition(blockCommentNode)) {
             // store as field, to share with child Checks
             blockCommentAst = blockCommentNode;
 
             final String treeCacheKey = blockCommentNode.getLineNo() + ":"
                     + blockCommentNode.getColumnNo();
 
-            ParseStatus result;
+            final ParseStatus result;
 
             if (TREE_CACHE.get().containsKey(treeCacheKey)) {
                 result = TREE_CACHE.get().get(treeCacheKey);
@@ -206,6 +213,29 @@ public abstract class AbstractJavadocCheck extends Check {
         return blockCommentAst;
     }
 
+    /**
+     * Checks Javadoc comment it's in right place.
+     * From Javadoc util documentation:
+     * "Placement of comments - Documentation comments are recognized only when placed
+     * immediately before class, interface, constructor, method, or field
+     * declarations -- see the class example, method example, and field example.
+     * Documentation comments placed in the body of a method are ignored. Only one
+     * documentation comment per declaration statement is recognized by the Javadoc tool."
+     *
+     * @param blockComment Block comment AST
+     * @return true if Javadoc is in right place
+     */
+    private static boolean isCorrectJavadocPosition(DetailAST blockComment) {
+        return BlockCommentPosition.isOnClass(blockComment)
+                || BlockCommentPosition.isOnInterface(blockComment)
+                || BlockCommentPosition.isOnEnum(blockComment)
+                || BlockCommentPosition.isOnMethod(blockComment)
+                || BlockCommentPosition.isOnField(blockComment)
+                || BlockCommentPosition.isOnConstructor(blockComment)
+                || BlockCommentPosition.isOnEnumConstant(blockComment)
+                || BlockCommentPosition.isOnAnnotationDef(blockComment);
+    }
+
     /**
      * Parses Javadoc comment as DetailNode tree.
      * @param javadocCommentAst
@@ -242,7 +272,7 @@ public abstract class AbstractJavadocCheck extends Check {
             // There are cases when antlr error listener does not handle syntax error
             if (parseErrorMessage == null) {
                 parseErrorMessage = new ParseErrorMessage(javadocCommentAst.getLineNo(),
-                        UNRECOGNIZED_ANTLR_ERROR_MESSAGE_KEY,
+                        MSG_KEY_UNRECOGNIZED_ANTLR_ERROR,
                         javadocCommentAst.getColumnNo(), ex.getMessage());
             }
 
@@ -413,7 +443,7 @@ public abstract class AbstractJavadocCheck extends Check {
      * @return token type from JavadocTokenTypes
      */
     private static int getTokenType(ParseTree node) {
-        int tokenType;
+        final int tokenType;
 
         if (node.getChildCount() == 0) {
             tokenType = ((TerminalNode) node).getSymbol().getType();
@@ -555,11 +585,6 @@ public abstract class AbstractJavadocCheck extends Check {
      */
     private static class DescriptiveErrorListener extends BaseErrorListener {
 
-        /**
-         * Parse error while rule recognition.
-         */
-        private static final String JAVADOC_PARSE_RULE_ERROR = "javadoc.parse.rule.error";
-
         /**
          * Offset is line number of beginning of the Javadoc comment. Log
          * messages should have line number in scope of file, not in scope of
@@ -609,15 +634,15 @@ public abstract class AbstractJavadocCheck extends Check {
             final int lineNumber = offset + line;
             final Token token = (Token) offendingSymbol;
 
-            if (JAVADOC_MISSED_HTML_CLOSE.equals(msg)) {
+            if (MSG_JAVADOC_MISSED_HTML_CLOSE.equals(msg)) {
                 errorMessage = new ParseErrorMessage(lineNumber,
-                        JAVADOC_MISSED_HTML_CLOSE, charPositionInLine, token.getText());
+                        MSG_JAVADOC_MISSED_HTML_CLOSE, charPositionInLine, token.getText());
 
                 throw new ParseCancellationException(msg);
             }
-            else if (JAVADOC_WRONG_SINGLETON_TAG.equals(msg)) {
+            else if (MSG_JAVADOC_WRONG_SINGLETON_TAG.equals(msg)) {
                 errorMessage = new ParseErrorMessage(lineNumber,
-                        JAVADOC_WRONG_SINGLETON_TAG, charPositionInLine, token.getText());
+                        MSG_JAVADOC_WRONG_SINGLETON_TAG, charPositionInLine, token.getText());
 
                 throw new ParseCancellationException(msg);
             }
@@ -628,7 +653,7 @@ public abstract class AbstractJavadocCheck extends Check {
                         CaseFormat.UPPER_UNDERSCORE, ruleName);
 
                 errorMessage = new ParseErrorMessage(lineNumber,
-                        JAVADOC_PARSE_RULE_ERROR, charPositionInLine, msg, upperCaseRuleName);
+                        MSG_JAVADOC_PARSE_RULE_ERROR, charPositionInLine, msg, upperCaseRuleName);
             }
         }
     }
