@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2015 the original author or authors.
+// Copyright (C) 2001-2016 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,10 +19,10 @@
 
 package com.puppycrawl.tools.checkstyle.checks.indentation;
 
-import static com.puppycrawl.tools.checkstyle.checks.indentation.AbstractExpressionHandler.MSG_CHILD_ERROR;
-import static com.puppycrawl.tools.checkstyle.checks.indentation.AbstractExpressionHandler.MSG_CHILD_ERROR_MULTI;
-import static com.puppycrawl.tools.checkstyle.checks.indentation.AbstractExpressionHandler.MSG_ERROR;
-import static com.puppycrawl.tools.checkstyle.checks.indentation.AbstractExpressionHandler.MSG_ERROR_MULTI;
+import static com.puppycrawl.tools.checkstyle.checks.indentation.IndentationCheck.MSG_CHILD_ERROR;
+import static com.puppycrawl.tools.checkstyle.checks.indentation.IndentationCheck.MSG_CHILD_ERROR_MULTI;
+import static com.puppycrawl.tools.checkstyle.checks.indentation.IndentationCheck.MSG_ERROR;
+import static com.puppycrawl.tools.checkstyle.checks.indentation.IndentationCheck.MSG_ERROR_MULTI;
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 
@@ -52,12 +52,9 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  * @author  jrichard
  */
 public class IndentationCheckTest extends BaseCheckTestSupport {
-    private static final Pattern NONEMPTY_LINE_REGEX =
-                    Pattern.compile(".*?\\S+.*?");
-
     private static final Pattern LINE_WITH_COMMENT_REGEX =
-                    Pattern.compile(".*?\\S+.*?(//indent:(\\d+)"
-                        + " exp:((>=\\d+)|(\\d+(,\\d+)*?))( warn)?)");
+                    Pattern.compile(".*?(//indent:(\\d+)"
+                        + " exp:((>=\\d+)|(\\d+(,\\d+)*?))( warn)?)$");
 
     private static final Pattern GET_INDENT_FROM_COMMENT_REGEX =
                     Pattern.compile("//indent:(\\d+).*?");
@@ -108,7 +105,7 @@ public class IndentationCheckTest extends BaseCheckTestSupport {
                                         lineNumber));
                     }
                 }
-                else if (NONEMPTY_LINE_REGEX.matcher(line).matches()) {
+                else if (!line.isEmpty()) {
                     throw new IllegalStateException(String.format(Locale.ROOT,
                                     "File \"%1$s\" has no indentation comment or its format "
                                                     + "malformed. Error on line: %2$d",
@@ -331,6 +328,24 @@ public class IndentationCheckTest extends BaseCheckTestSupport {
         verifyWarns(checkConfig, getPath("InputDifficultAnnotations.java"), expected);
     }
 
+    @Test
+    public void testAnnotationClosingParenthesisEndsInSameIndentationAsOpening() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(IndentationCheck.class);
+
+        checkConfig.addAttribute("basicOffset", "4");
+        checkConfig.addAttribute("forceStrictCondition", "true");
+        checkConfig.addAttribute("tabWidth", "4");
+
+        final String[] expected = {
+            "19: " + getCheckMessage(MSG_ERROR, ")", 16, 0),
+            "22: " + getCheckMessage(MSG_ERROR, ")",  8, 4),
+        };
+
+        verifyWarns(checkConfig,
+                getPath("InputAnnotationClosingParenthesisEndsInSameIndentationAsOpening.java"),
+                expected);
+    }
+
     @Test
     public void testAnonClassesFromGuava() throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(IndentationCheck.class);
@@ -1621,4 +1636,22 @@ public class IndentationCheckTest extends BaseCheckTestSupport {
         final String[] expected = EMPTY_EXPECTED;
         verifyWarns(checkConfig, getNonCompilablePath("InputLambda2.java"), expected, 0);
     }
+
+    @Test
+    public void testSeparatedStatements() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(IndentationCheck.class);
+        checkConfig.addAttribute("tabWidth", "4");
+        final String fileName = getPath("InputSeparatedStatements.java");
+        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        verifyWarns(checkConfig, fileName, expected);
+    }
+
+    @Test
+    public void testSeparatedLineWithJustSpaces() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(IndentationCheck.class);
+        checkConfig.addAttribute("tabWidth", "4");
+        final String fileName = getPath("InputSeparatedStatementWithSpaces.java");
+        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        verify(checkConfig, fileName, expected);
+    }
 }
