@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2015 the original author or authors.
+// Copyright (C) 2001-2016 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -571,4 +571,14 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
         };
         verify(checkConfig, getPath("InputJavadocMethodIgnoreNameRegex.java"), expected);
     }
+
+    @Test
+    public void testMethodsNotSkipWrittenJavadocs() throws Exception {
+        checkConfig.addAttribute("allowedAnnotations", "MyAnnotation");
+        final String[] expected = {
+            "7:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "BAD"),
+            "17:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "BAD"),
+        };
+        verify(checkConfig, getPath("InputJavadocMethodsNotSkipWritten.java"), expected);
+    }
 }
